## escapework/manager-medias

Módulo de mídias para integração com o escapework/manager.

## Instalação

Adicione os seguintes itens no seu `composer.json` e execute o comando um `composer update`:

```json
{
    "require": {
        "escapework/manager-medias": "1.0.*"
    },

    "repositories": [
        {
            "type": "git",
            "url": "git@bitbucket.org:escapecria/manager-medias.git"
        }
    ]
}
```

### ServiceProvider

Adicione a linha `'EscapeWork\Manager\Medias\Providers\ManagerServiceProvider'` no array de Service Providers no arquivo `app/config/app.php`.

### Configurações

Execute o comando abaixo para configurar o pacote:

```sh
$ php artisan manager:configure
```

### Linkando mídias com um cadastro

Para poder adicionar mídias em um cadastro (por exemplo notícias), é necessário duas coisas.

##### Implementar a interface `Mediable`

No model de seu cadastro, implemente a interface `EscapeWork\Manager\Medias\Helpers\Mediable`.

```
use EscapeWork\LaravelHelpers\BaseModel;
use EscapeWork\Manager\Medias\Helpers\Mediable;

class News extends BaseModel implements Mediable
{

    /**
     * Obrigarório implementar este método para utilizar as mídias
     */
    public function getMediaModel()
    {
        return 'EscapeWork\Manager\News\Models\News'; // caminho para o seu model
    }
}
```

##### Fazer o seed

Para fazer o seed, consulte o tópico abaixo.

##### Link para as fotos

Na tela de listagem dos registros, para linkar para a página de fotos, chame a seguinte função:

```
<a href="{{ manager_media_route($model) }}" class="btn btn-default" title="Editar">
    <span class="glyphicon glyphicon-camera"></span> fotos
</a>
```

### Seeds

Para não precisar criar manualmente os tamanhos em todos os servidores (local, produção, staging, etc), o ideal é você criar um seeder para isto. E o pacote possui um helper para ajudar você:

```php
    $data = array(
        'model'       => 'EscapeWork\Manager\News\Models\News',
        'model_title' => 'title',
        'model_route' => 'manager.noticias.index',
        'page_title'  => 'Notícias',
        'sizes'       => [
            [
                'prefix' => 'vga-',
                'width'  => 640,
                'height' => 480,
                'resize' => 1,
            ],
        ]
    );

    MediaModel::seed($data, $sizes);
```

Simplesmente declare o array (`$data`), e passe para o método `MediaModel::seed`. Os tamanhos já existentes serão atualizados, e os não existentes serão criados.

### Recriando os tamanhos

Existe um comando que você pode executar toda vez que criar um novo tamanho, para redimensionar as imagens antigas. Para isso, execute o seguinte comando:

```php
$ php artisan manager-medias:recreate-sizes
```

Toda vez que um novo tamanho é criado, é executada uma rotina onde todos os tamanhos do model em questão são recriados.

### Upload de imagens únicas

Caso o seu cadastro possua um único campo de imagem (o campo logotipo no cadastro de clientes, por exemplo), que não precisa ter toda a tela de mídias, você pode utilizar a classe `ImageUploader` e a interface `SingleMediaUpload`.

A interface `SingleMediaUpload` precisa ser implementada no seu model, e deve conter os seguintes métodos:

```php
use EscapeWork\LaravelHelpers\BaseModel;
use EscapeWork\Manager\Medias\Helpers\SingleMediaUpload;

class Client extends BaseModel implements SingleMediaUpload
{

    public function getSingleMediaFile()
    {
        return $this->logotipo;
    }

    public function getSingleMediaFolder()
    {
        return 'files/clients';
    }

    public function getSingleMediaName()
    {
        return 'logotipo';
    }
}
```

É necessário implementar os métodos `getSingleMediaFile`, `getSingleMediaFolder` e `getSingleMediaName`.

Depois, no seu repositório, cria um método que utilize a classe `SingleMediaUploader`.

```
use EscapeWork\LaravelHelpers\BaseRepository;
use EscapeWork\Manager\Medias\Helpers\SingleMediaUploader;

class ClientRepository extends BaseRepository
{

    public function uploadLogotipo($logo)
    {
        $field    = $this->model->getSingleMediaName();
        $uploader = new SingleMediaUploader(
            public_path(). '/' . $this->model->getSingleMediaFolder(), get_class($this->model)
        );

        if ($uploader->upload($logo, $this->model->exists, $this->model->getSingleMediaFile())) {
            $this->model->$field = $uploader->filename;
        }
    }
}

No seu Controller onde será feito o upload você pode chamar um método que fará o upload (No exemplo foi criado o método `uploadLogo`, mas pode ser criado o nome que preferir) passando por parâmetro o `Input` com a imagem, como no exemplo:

```php
public function store()
{
    $this->client->uploadLogotipo(Input::file('logotipo'));
}
```
