<?php namespace EscapeWork\Manager\Medias\Commands;

use Illuminate\Console\Command;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;
use EscapeWork\Manager\Medias\Repositories\MediaRepository;
use EscapeWork\Manager\Medias\Repositories\MediaModelRepository;
use EscapeWork\Manager\Medias\Resize\RecreateSizes;

class RecreateSizesCommand extends Command
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'manager-medias:recreate-sizes';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Percorre todas as mídias e recriar os tamanhos';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(
        MediaRepository $media,
        MediaModelRepository $mediaModel,
        RecreateSizes $recreateSizes)
    {
        parent::__construct();

        $this->mediaModel    = $mediaModel;
        $this->media         = $media;
        $this->recreateSizes = $recreateSizes;
    }

    /**
     * Execute the console command.
     *
     * @return void
     */
    public function fire()
    {
        $mediaModels = $this->mediaModel->all();

        foreach ($mediaModels as $mediaModel) {
            $this->media->setMediaModel($mediaModel->model);
            $this->recreateSizes->recreate($this->media);

            $this->info('Tamanhos recriados para o model ' . $mediaModel->model);
        }
    }

    /**
     * Get the console command arguments.
     *
     * @return array
     */
    protected function getArguments()
    {
        return array();
    }

    /**
     * Get the console command options.
     *
     * @return array
     */
    protected function getOptions()
    {
        return array();
    }

}
