<?php namespace EscapeWork\Manager\Medias\Providers;

use EscapeWork\Manager\Medias\Models\Media;
use EscapeWork\Manager\Medias\Models\MediaModelSize;
use EscapeWork\Manager\Medias\Commands\ConfigureCommand;
use EscapeWork\Manager\Medias\Commands\RecreateSizesCommand;
use Illuminate\Support\ServiceProvider;
use Route;
use Event;
use App;

class ManagerServiceProvider extends ServiceProvider
{

    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        $this->package('escapework/manager-medias', 'manager-medias', realpath(__DIR__ . '/../../../../'));

        require_once(__DIR__ . '/../../../../routes.php');
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->registerCommands();
        $this->listenEvents();
        $this->app->register('EscapeWork\Manager\Medias\Providers\MacrosServiceProvider');

        $this->app['config']->set('manager::packages.manager-medias', 'manager-medias');
    }

    protected function registerCommands()
    {
        $this->app['command.manager.medias.configure'] = $this->app->share(function($app)
        {
            return new ConfigureCommand;
        });

        $this->app['command.manager.medias.recreate'] = $this->app->share(function($app)
        {
            return new RecreateSizesCommand(
                $app->make('EscapeWork\Manager\Medias\Repositories\MediaRepository'),
                $app->make('EscapeWork\Manager\Medias\Repositories\MediaModelRepository'),
                $app->make('EscapeWork\Manager\Medias\Resize\RecreateSizes')
            );
        });

        $this->commands('command.manager.medias.configure', 'command.manager.medias.recreate');
    }

    protected function listenEvents()
    {
        Event::listen('manager-medias.model.destroy', function($model)
        {
            $media           = $this->app->make('EscapeWork\Manager\Medias\Repositories\MediaRepository');
            $media->setMediaModel(get_class($model));
            $media->model_id = $model->id;
            $media->deleteAll();
        });
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return array('command.manager.medias.configure');
    }

}
